timeintervaltools.scale_interval_durations_to_rational
======================================================

.. autofunction:: abjad.tools.timeintervaltools.scale_interval_durations_to_rational.scale_interval_durations_to_rational
